package ope.shopping;

/**
 * This class represents a person who has a name and some
 * money.
 * 
 * @author Kimmo Kiiski
 * @author Teemu Koskinen
 * @version 0.1
 * 
 * @see ShoppingCart
 */
public class Person {
   private String name;
   private double money;


   /**
    * Creates a new person object with given name. His/her
    * bank account balance will be initially zero.
    * 
    * @param name
    *           person's name
    */
   public Person(String name) {
      this.name = name;
      this.money = 0;
   }


   /**
    * Returns the name of this person.
    * 
    * @return the name of this person.
    */
   public String getName() {
      return this.name;
   }


   /**
    * Returns the balance of this person's bank account.
    * 
    * @return the money this person has.
    */
   public double getMoney() {
      return this.money;
   }


   /**
    * Adds the given amount of money to this person's bank
    * account.
    * 
    * @param amount
    *           the amount of money to be given.
    */
   public void receiveMoney(double amount) {
      this.money += amount;
   }


   /**
    * Charges some money from this person. The bank
    * account of this person will be charged for the
    * amount of money, but <b>only</b> if the person has
    * enough money. So, if the person doesn't have enough
    * money then the account balance will remain
    * unchanged.
    * 
    * @param amount
    *           the amount of money to be charged.
    * @return whether the charge was successful.
    */
   public boolean chargeMoney(double amount) {
      if (this.money > amount) {
         this.money -= amount;
         return true;
      } else {
         return false;
      }
   }
}
