package ope.shopping;

import java.util.ArrayList;

/**
 * This class represents a shopping cart. A shopping cart
 * has a customer as an owner and a list of products.
 * 
 * @author Kimmo Kiiski
 * @author Teemu Koskinen
 * @version 0.1
 * 
 * @see Person
 * @see Product
 */
public class ShoppingCart {

   private ArrayList<Product> products;
   private Person customer;


   /**
    * Creates a new empty shopping cart.
    * 
    * @param customer
    *           the owner of the new shopping cart
    */
   public ShoppingCart(Person customer) {
      // Set the customer
      this.customer = customer;
      // Create an empty product list
      this.products = new ArrayList<Product>();
   }


   /**
    * Adds a product to the shopping cart.
    * 
    * @param item
    *           the product to be added.
    */
   public void addProduct(Product item) {
      this.products.add(item);
   }


   /**
    * Returns the number of products in this shopping
    * cart.
    * 
    * @return the number of products in this shopping
    *         cart.
    */
   public int countProducts() {
      return this.products.size();
   }


   /**
    * Returns a product at the given index in this
    * shopping cart.
    * 
    * @param index
    *           the index of the product.
    * @return the product at the given index.
    */
   public Product getProduct(int index) {
      return this.products.get(index);
   }


   /**
    * Removes all the products from the shopping cart.
    */
   public void clear() {
      this.products.clear();
   }


   /**
    * Calculates the total price of products in this
    * shopping cart.
    * 
    * @return the total price of products in this shopping
    *         cart.
    */
   public double getTotalPrice() {
      double total = 0;
      for (Product item : this.products) {
         total += item.getPrice();
      }
      return total;
   }


   /**
    * Checks out this shopping cart. The customer of the
    * shopping cart will be charged and the cart will be
    * cleared. If the customer cannot afford to buy
    * products, money won't be charged and the cart will
    * remain unchanged. A standard output message is
    * printed, which describes whether the purchase was
    * successful or not.
    * 
    * @return whether the customer had enough money to buy
    *         the products.
    */
   public boolean checkOut() {
      double total = getTotalPrice();
      if (this.customer.chargeMoney(total)) {

         // The customer has enough money
         System.out.println(this.customer.getName()
            + " bought " + countProducts()
            + " products with " + total + " euros");
         clear();
         return true;

      } else {

         // The customer doesn't have enough money
         System.out.println(this.customer.getName()
            + " doesn't have enough money to buy "
            + countProducts() + " products with " + total
            + " euros");
         return false;

      }
   }
}
