package ope.shopping2;

/**
 * This class represents a Customer who has a name and some money.
 * 
 * @author Kimmo Kiiski
 * @author Teemu Koskinen
 * @version 0.2
 * 
 * @see ShoppingCart
 */
public class Customer {
	private String name;
	private double money;
	private ShoppingCart cart;

	/**
	 * Creates a new customer object with given name. His/her bank account
	 * balance will be initially zero.
	 * 
	 * @param name
	 *            the customer's name
	 */
	public Customer(String name) {
		this.name = name;
		this.money = 0;
	}

	/**
	 * Returns the name of this customer.
	 * 
	 * @return the name of this customer.
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Returns the balance of this person's bank account.
	 * 
	 * @return the money this person has without changing it.
	 */
	public double getBalance() {
		return this.money;
	}

	/**
	 * Adds the given amount of money to this person's bank account.
	 * 
	 * @param amount
	 *            the amount of money to be given.
	 */
	public void receiveMoney(double amount) {
		this.money += amount;
	}

	/**
	 * Checks out the person's shopping cart if he or she has sufficient amount
	 * of money.
	 * 
	 * @return boolean value indicating if checking out succeeded.
	 */
	public boolean checkOut() {
		double totalPrice = this.getCart().getTotalPrice();
		if (this.getBalance() >= totalPrice) {
			this.chargeMoney(totalPrice);
			return true;
		}
		return false;
	}

	/**
	 * Charges some money from this person. The bank account of this person will
	 * be charged for the amount of money, but <b>only</b> if the person has
	 * enough money. So, if the person doesn't have enough money then the
	 * account balance will remain unchanged.
	 * 
	 * @param amount
	 *            the amount of money to be charged.
	 * @return whether the charge was successful.
	 */
	public boolean chargeMoney(double amount) {
		if (this.getBalance() > amount) {
			this.money -= amount;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Returns the customer's shopping cart.
	 * 
	 * @return the shopping cart object of this customer.
	 */
	public ShoppingCart getCart() {
		return this.cart;
	}

	/**
	 * Empties the customer's shopping cart.
	 */
	public void clearCart() {
		this.getCart().clear();

	}

}
