package ope.shopping2;

/**
 * This class represents a product which has a name and a
 * price. The product can be placed into a shopping cart.
 * 
 * @author Kimmo Kiiski
 * @author Teemu Koskinen
 * @version 0.2
 * 
 * @see ShoppingCart
 */
public class Product {
   private String name;
   private double price;
   private int stockCount;


   /**
    * Creates a new product with the given name and price.
    * 
    * @param name
    *           the name of this product
    * @param price
    *           the price of this product
    */
   public Product(String name, double price, int stockCount) {
      this.name = name;
      this.price = price;
      this.stockCount = stockCount;
   }


   /**
    * Returns the name of this product.
    * 
    * @return the name of this product.
    */
   public String getName() {
      return this.name;
   }


   /**
    * Returns the price of this product.
    * 
    * @return the price of this product.
    */
   public double getPrice() {
      return this.price;
   }


   /**
    * Returns the stock count of this product.
    * 
    * @return the stock count of this product.
    */
   public int getStockCount() {
      return this.stockCount;
   }
   
   /**
    * Increases the stock count of this product by given amount.
    * 
    * @return the new stock count of this product.
    */
   public int addStock(int amount) {
	   this.stockCount += amount;
	   return this.stockCount;
   }
   
   /**
    * Tells if the product is in stock or not.
    * 
    * @return boolean value indicating if the product is available.
    */
   public boolean inStock() {
	   return this.getStockCount() > 0;
   }
   
   /**
    * Reduces the product's stock count by one, if it's available.
    * 
    * @return boolean value indicating if the reduction succeeded.
    */
   public boolean reduceStock() {
	   if ( this.inStock() ) {
		   this.stockCount--;
		   return true;
	   }
	   return false;
   }
   
   /**
    * Overrides Object-classes toString method which creates a String
    * representation for this Product instance.
    * 
    * @return String representation of this product.
    */
   public String toString() {
      return this.getName() + " (" + this.getPrice() + " euros, " + this.getStockCount() + " in stock)";
   }
}
