package ope.shopping2;

import java.util.ArrayList;

/**
 * This class represents a shopping cart. A shopping cart has a customer as an
 * owner and a list of products.
 * 
 * @author Kimmo Kiiski
 * @author Teemu Koskinen
 * @version 0.2
 * 
 * @see Customer
 * @see Product
 */
public class ShoppingCart {

	private ArrayList<Product> products;

	/**
	 * Creates a new empty and anonymous shopping cart.
	 */
	public ShoppingCart() {
		// Create an empty product list
		this.products = new ArrayList<Product>();
	}

	/**
	 * Adds a product to the shopping cart if it is available. Also calls the
	 * reduceStock-method that updates the stock count for this Product.
	 * 
	 * @param item
	 *            the product to be added.
	 */
	public void addProduct(Product item) {
		this.products.add(item);
		item.reduceStock();
	}

	/**
	 * Returns the number of products in this shopping cart.
	 * 
	 * @return the number of products in this shopping cart.
	 */
	public int countProducts() {
		return this.products.size();
	}

	/**
	 * Returns a product at the given index in this shopping cart.
	 * 
	 * @param index
	 *            the index of the product.
	 * @return the product at the given index.
	 */
	public Product getProduct(int index) {
		return this.products.get(index);
	}

	/**
	 * Removes all the products from the shopping cart.
	 */
	public void clear() {
		this.products.clear();
	}

	/**
	 * Calculates the total price of products in this shopping cart.
	 * 
	 * @return the total price of products in this shopping cart.
	 */
	public double getTotalPrice() {
		double total = 0;
		for (Product item : this.products) {
			total += item.getPrice();
		}
		return total;
	}
}
